<?php

namespace Lc\SovBundle\Model\User;

use Doctrine\ORM\Mapping as ORM;
use Lc\SovBundle\Doctrine\EntityInterface;
use Symfony\Component\Security\Core\User\UserInterface;

/**
 * @ORM\MappedSuperclass()
 */
abstract class User implements EntityInterface, UserInterface
{
        /**
         * @ORM\Column(type="string", length=180, unique=true)
         */
        protected $email;

        /**
         * @ORM\Column(type="json")
         */
        protected $roles = [];

        /**
         * @var string The hashed password
         * @ORM\Column(type="string")
         */
        protected $password;

        /**
         * @ORM\Column(type="string", length=255, nullable=true)
         */
        protected $lastname;

        /**
         * @ORM\Column(type="string", length=255, nullable=true)
         */
        protected $firstname;

        /**
         * @ORM\Column(type="boolean")
         */
        protected $isVerified = false;



        public function getEmail(): ?string
        {
                return $this->email;
        }

        public function setEmail(string $email): self
        {
                $this->email = $email;

                return $this;
        }

        /**
         * A visual identifier that represents this user.
         *
         * @see UserInterface
         */
        public function getUsername(): string
        {
                return (string)$this->email;
        }

        /**
         * @see UserInterface
         */
        public function getRoles(): array
        {
                $roles = $this->roles;
                // guarantee every user at least has ROLE_USER
                $roles[] = 'ROLE_USER';

                return array_unique($roles);
        }

        public function setRoles(array $roles): self
        {
                $this->roles = $roles;

                return $this;
        }

        /**
         * @see UserInterface
         */
        public function getPassword(): string
        {
                return (string)$this->password;
        }

        public function setPassword(string $password): self
        {
                $this->password = $password;

                return $this;
        }

        /**
         * @see UserIn
         */
        public function getSalt()
        {
                // not needed when using the "bcrypt" algorithm in security.yaml
        }

        /**
         * @see UserInterface
         */
        public function eraseCredentials()
        {
                // If you store any temporary, sensitive data on the user, clear it here
                // $this->plainPassword = null;
        }

        public function getLastname(): ?string
        {
                return $this->lastname;
        }

        public function setLastname(?string $lastname): self
        {
                $this->lastname = $lastname;

                return $this;
        }

        public function getFirstname(): ?string
        {
                return $this->firstname;
        }

        public function setFirstname(?string $firstname): self
        {
                $this->firstname = $firstname;

                return $this;
        }

        public function getName(): ?string
        {
            return $this->getFirstname(). ' '.strtoupper($this->getLastname());
        }

        public function isVerified(): bool
        {
                return $this->isVerified;
        }

        public function setIsVerified(bool $isVerified): self
        {
                $this->isVerified = $isVerified;

                return $this;
        }
}
