<?php

namespace Lc\SovBundle\Twig;

use Doctrine\ORM\EntityManagerInterface;
use Liip\ImagineBundle\Imagine\Cache\CacheManager;
use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\HttpKernel\KernelInterface;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use Twig\Extension\AbstractExtension;
use Twig\TwigFilter;
use Twig\TwigFunction;

class TwigExtension extends AbstractExtension
{
        protected $em;
        protected $kernel;
        protected $parameterBag;
        protected $cacheManager;
        protected $requestStack;
        protected $router;

        public function __construct(KernelInterface $kernel, ParameterBagInterface $parameterBag, CacheManager $cacheManager, EntityManagerInterface $entityManager, RequestStack $requestStack,UrlGeneratorInterface $router)
        {
                $this->kernel = $kernel;
                $this->parameterBag = $parameterBag;
                $this->cacheManager = $cacheManager;
                $this->em = $entityManager;
                $this->requestStack = $requestStack;
                $this->router = $router;
        }

        public function getFunctions()
        {
                return array(
                        new TwigFunction('lc_liip', [$this, 'lcLiip']),
                        new TwigFunction('homepage_route', [$this, 'homepageRoute']),
                        new TwigFunction('page_by_dev_alias', [$this, 'getPageByDevAlias']),
                        new TwigFunction('translated_urls', [$this, 'getTranslatedUrls'])
                );
        }


        public function getFilters()
        {
                return [
                        new TwigFilter('lc_cache', [$this, 'lcCache']),
                ];
        }

        public function lcCache($file)
        {
                $cacheTime = filemtime($this->kernel->getProjectDir() . '/public' . $file);
                if ($cacheTime) {
                        return $file . '?c=' . $cacheTime;
                } else {
                        return $file . "?c=0";
                }
        }

        public function lcLiip($path, $thumb = 'tile', $default = 'default.jpg')
        {
                if (substr($path, 0, 1) === '/') $path = substr($path, 1);

                if ($path) {
                        $fileManagerFolder = substr($this->getFileManagerFolder(), 1)  ;

                        if (strpos($path, $fileManagerFolder) === false) {
                                $path = $fileManagerFolder . '/' . $path;
                        }

                        if (file_exists($path)) {
                                return $this->cacheManager->getBrowserPath($path, $thumb);
                        }
                }

                return $this->cacheManager->getBrowserPath($this->getFileManagerFolder() . '/' . $default, $thumb);
        }

        function getTranslatedUrls()
        {
                $ret = array();
                $langs = $this->parameterBag->get('app.locales');
                $currentRoute = $this->requestStack->getCurrentRequest()->get('_route');

                $params = array_merge((array)$this->requestStack->getCurrentRequest()->get('_route_params'), $_GET);

                if ($currentRoute) {
                        foreach($langs as $lg) {
                                $ret[$lg] = $this->router->generate($currentRoute, array_merge($params, array('_locale'=>$lg)));
                        }
                }

                return $ret;
        }

        public function getFileManagerFolder()
        {
                return $this->parameterBag->get('app.path_uploads');
        }

        public function homepageRoute(){
            return $this->parameterBag->get('lc_sov.homepage_route');
        }

}
